@@ -5,6 +5,11 @@ from tuxmake.build import build, supported, defaults
 from tuxmake.exceptions import TuxMakeException
 
 
+def key_value(s):
+    parts = s.split("=")
+    return (parts[0], "=".join(parts[1:]))
+
+
 def main(*argv):
     if not argv:
         argv = sys.argv[1:]
@@ -57,6 +62,19 @@ def main(*argv):
         type=str,
         help=f"Toolchain to use in the build. Default: none (use whatever Linux uses by default). Supported: {', '.join(supported.toolchains)}; request specific versions by appending \"-N\" (e.g. gcc-10, clang-9).",
     )
+    buildenv.add_argument(
+        "-w",
+        "--wrapper",
+        type=str,
+        help=f"Compiler wrapper to use in the build. Default: none. Supported: {', '.join(supported.wrappers)}. When used with containers, either the wrapper binary must be available in the container image, OR you can pass --wrapper=/path/to/WRAPPER and WRAPPER will be bind mounted in /usr/local/bin inside the container (for this to work WRAPPER needs to be a static binary, or have its shared library dependencies available inside the container).",
+    )
+    buildenv.add_argument(
+        "-e",
+        "--environment",
+        type=key_value,
+        action="append",
+        help="Set environment variables for the build. Format: KEY=VALUE",
+    )
     buildenv.add_argument(
         "-j",
         "--jobs",
@@ -87,6 +105,8 @@ def main(*argv):
     )
 
     options = parser.parse_args(argv)
+    if options.environment:
+        options.environment = dict(options.environment)
 
     build_args = {k: v for k, v in options.__dict__.items() if v}
     try:
