@@ -26,6 +26,11 @@ class UnsupportedToolchain(TuxMakeException):
     pass
 
 
+class UnsupportedWrapper(TuxMakeException):
+    msg = "Unsupported compiler wrapper: {name}"
+    pass
+
+
 class UnsupportedKconfig(TuxMakeException):
     msg = "Unsupported kconfig: {name}"
 
@@ -36,3 +41,21 @@ class InvalidKConfig(TuxMakeException):
 
 class UnsupportedKconfigFragment(TuxMakeException):
     msg = "Unsupported kconfig fragment: {name}"
+
+
+class InvalidRuntimeError(TuxMakeException):
+    msg = "Invalid runtime: {name}"
+
+
+class RuntimePreparationFailed(TuxMakeException):
+    msg = "Runtime preparation failed: {name}"
+
+
+class UnsupportedMetadata(TuxMakeException):
+    msg = "Unsupported metadata extractor: {name}"
+    pass
+
+
+class UnsupportedMetadataType(TuxMakeException):
+    msg = "Unsupported metadata type: {name}"
+    pass
